#!/usr/bin/bash
script_path=$(dirname $(readlink -f $0))

cd $script_path
# 开启对 nmap 扫描行为的探测

# 清空现有的规则链
iptables -F

# 允许所有出站流量
iptables -P OUTPUT ACCEPT

# 允许所有已建立的连接
iptables -A INPUT -m state --state ESTABLISHED,RELATED -j ACCEPT

# 允许本地环回接口的流量
iptables -A INPUT -i lo -j ACCEPT

# 允许 SSH 连接
iptables -A INPUT -p tcp --dport 22 -j ACCEPT

# 探测 nmap 扫描行为
# 只检测 TCP 的 SYN 操作
iptables -A INPUT -p tcp --syn -m state --state NEW -m recent --name NMAP_SCAN --set
iptables -A INPUT -p tcp --syn -m state --state NEW -m recent --name NMAP_SCAN --update --seconds 10 --hitcount 5 -j LOG --log-prefix "NMAP_SCAN: " --log-level 4 --log-uid

# 保存规则到默认路径
iptables-save > /etc/iptables/rules.v4 2>/dev/null || iptables-save > /etc/sysconfig/iptables

cp detection.conf /etc/rsyslog.d/

# 重启 rsyslog 服务
systemctl restart rsyslog

echo "iptables 规则已开启，开始探测 nmap 扫描行为，并将日志记录到系统日志。"
