#!/usr/bin/bash

SYSTEM_PATH=/etc/pam.d/system-auth
PWD_PATH=/etc/pam.d/password-auth

ARCH=$(uname -m)

function nfs_factor(){
	CONTENT="auth     required    pam_genpem_sig_and_verify.so"
	if [ "$1" = "true" ];then
		sed -i "/pam_genpem_sig_and_verify\.so/d" $SYSTEM_PATH
		sed -i "/pam_genpem_sig_and_verify\.so/d" $PWD_PATH
		LINE_NUMBER=$(grep -n 'auth\s*sufficient\s*pam_unix\.so' "$SYSTEM_PATH" | cut -d: -f1)
		sed -i "${LINE_NUMBER}i $CONTENT" $SYSTEM_PATH
		
		LINE_NUMBER=$(grep -n 'auth\s*sufficient\s*pam_unix\.so' "$PWD_PATH" | cut -d: -f1)
		sed -i "${LINE_NUMBER}i $CONTENT" $PWD_PATH
	else
		sed -i "/pam_genpem_sig_and_verify\.so/d" $SYSTEM_PATH
		sed -i "/pam_genpem_sig_and_verify\.so/d" $PWD_PATH
	fi
}

CONFIG_FILE="/etc/ssh/sshd_config"
BANNER_LINE="Banner /etc/.sshbanner.txt"

function nfs_otpw(){
	CONTENT="auth     sufficient    pam_otpw.so    nolock"
	if [ "$1" = "true" ];then
		sed -i "/pam_otpw\.so/d" $SYSTEM_PATH
		sed -i "/pam_otpw\.so/d" $PWD_PATH
		
		LINE_NUMBER=$(grep -n 'auth\s*sufficient\s*pam_unix\.so' "$SYSTEM_PATH" | cut -d: -f1)
		sed -i "${LINE_NUMBER}i $CONTENT" $SYSTEM_PATH
		
		LINE_NUMBER=$(grep -n 'auth\s*sufficient\s*pam_unix\.so' "$PWD_PATH" | cut -d: -f1)
		sed -i "${LINE_NUMBER}i $CONTENT" $PWD_PATH
		
        #sed -i '/^'$BANNER_LINE'$/d' "$CONFIG_FILE"
        escaped_banner=$(echo "$BANNER_LINE" | sed 's/\//\\\//g')
        sed -i "/^$escaped_banner$/d" "$CONFIG_FILE"
        if ! tail -n 1 "$CONFIG_FILE" | grep -q "^$BANNER_LINE$"; then
            # 在最后一行添加 Banner 行
            echo "$BANNER_LINE" >> "$CONFIG_FILE"
        fi
		
		systemctl reload sshd
		
		bash /usr/bin/sshbannertopam-start.sh
	else
		sed -i "/pam_otpw\.so/d" $SYSTEM_PATH
		sed -i "/pam_otpw\.so/d" $PWD_PATH
		
		#sed -i '/^'$BANNER_LINE'$/d' "$CONFIG_FILE"
        escaped_banner=$(echo "$BANNER_LINE" | sed 's/\//\\\//g')
        sed -i "/^$escaped_banner$/d" "$CONFIG_FILE"
		systemctl reload sshd
		bash /usr/bin/sshbannertopam-stop.sh
	fi
}

function nfs_ukey(){
	CONTENT="auth     sufficient    pam_nfsukey_verify.so"
	if [ "$1" = "true" ];then
		sed -i "/pam_nfsukey_verify\.so/d" $SYSTEM_PATH
		sed -i "/pam_nfsukey_verify\.so/d" $PWD_PATH
		
		LINE_NUMBER=$(grep -n 'auth\s*sufficient\s*pam_unix\.so' "$SYSTEM_PATH" | cut -d: -f1)
		sed -i "${LINE_NUMBER}i $CONTENT" $SYSTEM_PATH
		
		LINE_NUMBER=$(grep -n 'auth\s*sufficient\s*pam_unix\.so' "$PWD_PATH" | cut -d: -f1)
		sed -i "${LINE_NUMBER}i $CONTENT" $PWD_PATH
		
		LINE_NUMBER=$(grep -n '^[^#]*auth\s*sufficient\s*pam_unix\.so' "$PWD_PATH" | cut -d: -f1)
		if [ -n "$LINE_NUMBER" ]; then
			sed -i "${LINE_NUMBER}s/^/#/" "$PWD_PATH"
		fi
		
		LINE_NUMBER=$(grep -n '^[^#]*auth\s*sufficient\s*pam_unix\.so' "$SYSTEM_PATH" | cut -d: -f1)
		if [ -n "$LINE_NUMBER" ]; then
			sed -i "${LINE_NUMBER}s/^/#/" "$SYSTEM_PATH"
		fi
		
	else
		sed -i "/pam_nfsukey_verify\.so/d" $SYSTEM_PATH
		sed -i "/pam_nfsukey_verify\.so/d" $PWD_PATH
		
		LINE_NUMBER=$(grep -n '^#.*auth\s*sufficient\s*pam_unix\.so' "$PWD_PATH" | cut -d: -f1)
		if [ -n "$LINE_NUMBER" ]; then
			sed -i "${LINE_NUMBER}s/^#//" "$PWD_PATH"
		fi
		
		LINE_NUMBER=$(grep -n '^#.*auth\s*sufficient\s*pam_unix\.so' "$SYSTEM_PATH" | cut -d: -f1)
		if [ -n "$LINE_NUMBER" ]; then
			sed -i "${LINE_NUMBER}s/^#//" "$SYSTEM_PATH"
		fi

	fi
}


if [ "$1" = "0" ];then
	nfs_factor "false"
	nfs_otpw "false"
	nfs_ukey "false"
	echo "0"
elif [ "$1" = "1" ];then
	nfs_factor "true"
	nfs_otpw "false"
	nfs_ukey "false"
	echo "1"
elif [ "$1" = "2" ];then
	nfs_factor "false"
	nfs_otpw "true"
	nfs_ukey "false"
	echo "2"
elif [ "$1" = "3" ];then
	nfs_factor "false"
	nfs_otpw "false"
	nfs_ukey "true"
	echo "3"
else
	echo "100"
fi






